@@ -606,6 +606,7 @@ class DSLibrary(object):
         # detect SQL target
         sql_source = kwargs.get("sql_source")
         sql_table = kwargs.get("sql_table")
+        sql_flavor = kwargs.get("sql_flavor")
         if sql_source or sql_table:
             # write data to an SQL table
             sql_source = sql_source or resource_name
@@ -613,7 +614,7 @@ class DSLibrary(object):
             content = _coerce_to_dataframe(content)
             try:
                 table = sql_table or resource_name
-                for sql, params in dataframe_to_sql(content, table_name=table, append=append):
+                for sql, params in dataframe_to_sql(content, table_name=table, append=append, flavor=sql_flavor):
                     db_conn.cursor().execute(sql, params)
             finally:
                 db_conn.close()
@@ -850,6 +851,25 @@ class DSLibrary(object):
         else:
             raise ValueError("expected content or filename")
 
+    def save_dataframe(self, uri: str, content, **kwargs):
+        """
+        Save a dataframe to various places.
+
+        :param uri:         Named destination or filename.
+        :param content:     A pandas-like dataframe, or a [] or {} that pandas can interpret as a dataframe.
+        :param kwargs:      See write_resource().
+        """
+        # a dataframe
+        if hasattr(content, "columns"):
+            return self.write_resource(uri, content, **kwargs)
+        if isinstance(content, (pandas.Series, numpy.ndarray, pandas.Index)):
+            content = _coerce_to_dataframe(content)
+        # try to force into a dataframe
+        df_args = {}
+        if "columns" in kwargs:
+            df_args["columns"] = kwargs.pop("columns")
+        return self.write_resource(uri, pandas.DataFrame(content, **df_args), **kwargs)
+
     def multi_part_upload(self, resource_name: str, chunk: (bytes, bytearray), upload_id: str=None, sequence: int=None, done: bool=False, **kwargs):
         """
         Manage a large upload.
