@@ -771,6 +771,32 @@ class TestFront(unittest.TestCase):
         MyInst().write_resource('f', pandas.DataFrame({"x": [1, 2], "y": [10, 20]}), format_options={"format": "csv", "sep": ";"})
         self.assertEqual(files["f"], 'x;y\n1;10\n2;20\n')
 
+    def test_save_dataframe(self):
+        """
+        Dask writes data into folders, in the manner of spark.
+        """
+        tmpdir = tempfile.mkdtemp()
+        try:
+            class MyInst(DSLibrary):
+                def _opener(self, path: str, mode: str, **kwargs):
+                    return open(path, mode)
+            fn = os.path.join(tmpdir, "x.csv")
+            df = pandas.DataFrame({"x": list(range(100))})
+            MyInst().save_dataframe(fn, df)
+            df = MyInst().load_dataframe(fn, format_options={"delimiter": "\0"})
+            self.assertEqual(list(df.x), list(range(100)))
+            # data with named columns
+            MyInst().save_dataframe(fn, range(100), columns=["y"])
+            df = MyInst().load_dataframe(fn, format_options={"delimiter": "\0"})
+            self.assertEqual(list(df.y), list(range(100)))
+            # JSON data pandas understands
+            MyInst().save_dataframe(fn, {"z": list(range(100))})
+            df = MyInst().load_dataframe(fn, format_options={"delimiter": "\0"})
+            self.assertEqual(list(df.z), list(range(100)))
+        finally:
+            shutil.rmtree(tmpdir)
+
+
     def test_from_sql_2(self):
         log = []
         class MyInst(DSLibrary):
